==> bitsensor-node-js-core-1.0.2.tgz: package/core/api_connector.js <==
//Core Api Connector
var Log = require('./../util/log');
var request = require('request');
var Meta = require('./constants').Meta;

var ApiConnector = function () {
  this.user = '';
  this.uri = '';
  this.datapoint = {};
  this.apiKey = '';
  this.action = '';
};

ApiConnector.ACTION_AUTHORIZE = 'authorize';
ApiConnector.ACTION_LOG = 'log';

/**
 * @param {String} user
 * @param {String} apiKey
 * @returns {ApiConnector}
 */
ApiConnector.prototype.from = function (user, apiKey) {
  this.user = user;
  this.apiKey = apiKey;
  return this;
};

/**
 * @param {Datapoint} datapoint
 * @returns {ApiConnector}
 */
ApiConnector.prototype.with = function (datapoint) {
  this.datapoint = datapoint;
  return this;
};

/**
 * @param {String} uri
 * @returns {ApiConnector}
 */
ApiConnector.prototype.to = function (uri) {
  this.uri = uri;
  return this;
};

/**
 * @param {String} action
 * @returns {ApiConnector}
 */
ApiConnector.prototype.post = function (action) {
  this.action = action;
  return this;
};

ApiConnector.prototype.send = function () {
  this.datapoint.putMeta(Meta.USER, this.user);
  this.datapoint.putMeta(Meta.API_KEY, this.apiKey);

  var content = {
    [Meta.DATA]: JSON.stringify(this.datapoint),
    [Meta.ENCRYPTION]: false
  };

  request({
    url: this.uri + "/" + this.action,
    method: this.getRequestType(this.action),
    json: content,
  }, function (error, response, body) {

  });
};

/**
 * @param {String} action
 * @returns {String}
 */
ApiConnector.prototype.getRequestType = function (action) {
  switch (action) {
    case ApiConnector.ACTION_AUTHORIZE:
      return 'POST';
    case ApiConnector.ACTION_LOG:
      return 'POST';
    default:
      return 'GET';
  }
};

module.exports = ApiConnector;

==> bitsensor-node-js-core-1.1.0.tgz: package/core/api_connector.js <==
//Core Api Connector
var request = require('request');
var Meta = require('./constants').Meta;

var ApiConnector = function () {
  this.user = '';
  this.uri = '';
  this.datapoint = {};
  this.apiKey = '';
  this.action = '';
};

ApiConnector.ACTION_AUTHORIZE = 'authorize';
ApiConnector.ACTION_LOG = 'log';

/**
 * @param {String} user
 * @param {String} apiKey
 * @returns {ApiConnector}
 */
ApiConnector.prototype.from = function (user, apiKey) {
  this.user = user;
  this.apiKey = apiKey;
  return this;
};

/**
 * @param {Datapoint} datapoint
 * @returns {ApiConnector}
 */
ApiConnector.prototype.with = function (datapoint) {
  this.datapoint = datapoint;
  return this;
};

/**
 * @param {String} uri
 * @returns {ApiConnector}
 */
ApiConnector.prototype.to = function (uri) {
  this.uri = uri;
  return this;
};

/**
 * @param {String} action
 * @returns {ApiConnector}
 */
ApiConnector.prototype.post = function (action) {
  this.action = action;
  return this;
};

ApiConnector.prototype.send = function () {
  this.datapoint.meta[Meta.USER] = this.user;
  this.datapoint.meta[Meta.API_KEY] = this.apiKey;

  var content = {
    [Meta.DATA]: JSON.stringify(this.datapoint),
    [Meta.ENCRYPTION]: false
  };

  request({
    url: this.uri + "/" + this.action,
    method: this.getRequestType(this.action),
    json: content,
  }, function (error, response, body) {

  });
};

/**
 * @param {String} action
 * @returns {String}
 */
ApiConnector.prototype.getRequestType = function (action) {
  switch (action) {
    case ApiConnector.ACTION_AUTHORIZE:
      return 'POST';
    case ApiConnector.ACTION_LOG:
      return 'POST';
    default:
      return 'GET';
  }
};

module.exports = ApiConnector;
